==> unity-ads-4.14.1-sources.jar: com/unity3d/ads/adplayer/ExposedFunctionLocation.kt <==
package com.unity3d.ads.adplayer

fun interface ExposedFunction : suspend (Array<Any>) -> Any

object ExposedFunctionLocation {
    const val GET_AD_CONTEXT = "com.unity3d.services.ads.api.AdViewer.getAdContext"
    const val GET_SCREEN_HEIGHT = "com.unity3d.services.core.api.DeviceInfo.getScreenHeight"
    const val GET_SCREEN_WIDTH = "com.unity3d.services.core.api.DeviceInfo.getScreenWidth"
    const val GET_CONNECTION_TYPE = "com.unity3d.services.core.api.DeviceInfo.getConnectionType"
    const val GET_DEVICE_VOLUME = "com.unity3d.services.core.api.DeviceInfo.getDeviceVolume"
    const val GET_DEVICE_MAX_VOLUME = "com.unity3d.services.core.api.DeviceInfo.getDeviceMaxVolume"
    const val LOAD_COMPLETE = "com.unity3d.services.ads.api.AdViewer.loadComplete"
    const val OM_START_SESSION = "com.unity3d.services.ads.api.AdViewer.omidStartSession"
    const val OM_FINISH_SESSION = "com.unity3d.services.ads.api.AdViewer.omidFinishSession"
    const val OM_IMPRESSION = "com.unity3d.services.ads.api.AdViewer.omidImpression"
    const val OM_GET_DATA = "com.unity3d.services.ads.api.AdViewer.omidGetData"
    const val UPDATE_CAMPAIGN_STATE = "com.unity3d.services.ads.api.AdViewer.updateCampaignState"
    const val MARK_CAMPAIGN_STATE_SHOWN = "com.unity3d.services.ads.api.AdViewer.markCampaignStateAsShown"
    const val LOAD_ERROR = "com.unity3d.services.ads.api.AdViewer.loadError"
    const val SEND_OPERATIVE_EVENT = "com.unity3d.services.ads.api.AdViewer.sendOperativeEvent"
    const val OPEN_URL = "com.unity3d.services.ads.api.AdViewer.openUrl"
    const val SET_ORIENTATION = "com.unity3d.services.ads.api.AdViewer.setOrientation"
    const val CANCEL_SHOW_TIMEOUT = "com.unity3d.services.ads.api.AdViewer.cancelShowTimeout"
    const val STARTED = "com.unity3d.services.ads.api.AdViewer.started"
    const val CLICKED = "com.unity3d.services.ads.api.AdViewer.clicked"
    const val COMPLETED = "com.unity3d.services.ads.api.AdViewer.completed"
    const val FAILED = "com.unity3d.services.ads.api.AdViewer.failed"
    const val STORAGE_READ = "com.unity3d.services.core.api.Storage.read"
    const val STORAGE_WRITE = "com.unity3d.services.core.api.Storage.write"
    const val STORAGE_CLEAR = "com.unity3d.services.core.api.Storage.clear"
    const val STORAGE_DELETE = "com.unity3d.services.core.api.Storage.delete"
    const val STORAGE_GET_KEYS = "com.unity3d.services.core.api.Storage.getKeys"
    const val STORAGE_GET = "com.unity3d.services.core.api.Storage.get"
    const val STORAGE_SET = "com.unity3d.services.core.api.Storage.set"
    const val GET_SESSION_TOKEN = "com.unity3d.services.ads.api.AdViewer.getSessionToken"
    const val GET_PRIVACY_FSM = "com.unity3d.services.ads.api.AdViewer.getPrivacyFsm"
    const val SET_PRIVACY_FSM = "com.unity3d.services.ads.api.AdViewer.setPrivacyFsm"
    const val SET_PRIVACY = "com.unity3d.services.ads.api.AdViewer.setPrivacyPayload"
    const val GET_PRIVACY = "com.unity3d.services.ads.api.AdViewer.getPrivacyPayload"
    const val BROADCAST_EVENT = "com.unity3d.services.ads.api.AdViewer.broadcastEvent"
    const val GET_ALLOWED_PII = "com.unity3d.services.ads.api.AdViewer.getPrivacyAllowedPii"
    const val SET_ALLOWED_PII = "com.unity3d.services.ads.api.AdViewer.setPrivacyAllowedPii"
    const val REFRESH_AD_DATA = "com.unity3d.services.ads.api.AdViewer.refreshAdData"
    const val UPDATE_TRACKING_TOKEN = "com.unity3d.services.ads.api.AdViewer.updateTrackingToken"
    const val REQUEST_GET = "com.unity3d.services.core.api.Request.get"
    const val REQUEST_POST = "com.unity3d.services.core.api.Request.post"
    const val REQUEST_HEAD = "com.unity3d.services.core.api.Request.head"
    const val SEND_PRIVACY_UPDATE_REQUEST = "com.unity3d.services.ads.api.AdViewer.sendPrivacyUpdateRequest"
    const val SEND_DIAGNOSTIC_EVENT = "com.unity3d.services.ads.api.AdViewer.sendDiagnosticEvent"
    const val INCREMENT_BANNER_IMPRESSION_COUNT = "com.unity3d.services.ads.api.AdViewer.incrementBannerImpressionCount"
    const val DOWNLOAD = "com.unity3d.services.ads.api.AdViewer.download"
    const val IS_FILE_CACHED = "com.unity3d.services.ads.api.AdViewer.isFileCached"
    const val LEFT_APPLICATION = "com.unity3d.services.ads.api.AdViewer.leftApplication"
    const val IS_ATTRIBUTION_AVAILABLE = "com.unity3d.services.ads.api.AdViewer.isAttributionAvailable"
    const val ATTRIBUTION_REGISTER_VIEW = "com.unity3d.services.ads.api.AdViewer.attributionRegisterView"
    const val ATTRIBUTION_REGISTER_CLICK = "com.unity3d.services.ads.api.AdViewer.attributionRegisterClick"
    const val LOAD_SCAR_AD = "com.unity3d.services.ads.api.AdViewer.loadScarAd"
    const val SHOW_SCAR_AD = "com.unity3d.services.ads.api.AdViewer.showScarAd"
    const val HEADER_BIDDING_TOKEN_INCREMENT_WINS = "com.unity3d.services.ads.api.AdViewer.hbTokenIncrementWins"
    const val HEADER_BIDDING_TOKEN_INCREMENT_STARTS = "com.unity3d.services.ads.api.AdViewer.hbTokenIncrementStarts"
    const val HEADER_BIDDING_TOKEN_RESET = "com.unity3d.services.ads.api.AdViewer.hbTokenReset"
    const val LOAD_OFFERWALL_AD = "com.unity3d.services.ads.api.AdViewer.loadOfferwallAd"
    const val SHOW_OFFERWALL_AD = "com.unity3d.services.ads.api.AdViewer.showOfferwallAd"
}

==> unity-ads-4.16.3-sources.jar: com/unity3d/ads/adplayer/ExposedFunctionLocation.kt <==
package com.unity3d.ads.adplayer

fun interface ExposedFunction : suspend (Array<Any>) -> Any

object ExposedFunctionLocation {
    const val GET_AD_CONTEXT = "com.unity3d.services.ads.api.AdViewer.getAdContext"
    const val GET_SCREEN_HEIGHT = "com.unity3d.services.core.api.DeviceInfo.getScreenHeight"
    const val GET_SCREEN_WIDTH = "com.unity3d.services.core.api.DeviceInfo.getScreenWidth"
    const val GET_CONNECTION_TYPE = "com.unity3d.services.core.api.DeviceInfo.getConnectionType"
    const val GET_DEVICE_VOLUME = "com.unity3d.services.core.api.DeviceInfo.getDeviceVolume"
    const val GET_DEVICE_MAX_VOLUME = "com.unity3d.services.core.api.DeviceInfo.getDeviceMaxVolume"
    const val LOAD_COMPLETE = "com.unity3d.services.ads.api.AdViewer.loadComplete"
    const val OM_START_SESSION = "com.unity3d.services.ads.api.AdViewer.omidStartSession"
    const val OM_FINISH_SESSION = "com.unity3d.services.ads.api.AdViewer.omidFinishSession"
    const val OM_IMPRESSION = "com.unity3d.services.ads.api.AdViewer.omidImpression"
    const val OM_GET_DATA = "com.unity3d.services.ads.api.AdViewer.omidGetData"
    const val UPDATE_CAMPAIGN_STATE = "com.unity3d.services.ads.api.AdViewer.updateCampaignState"
    const val MARK_CAMPAIGN_STATE_SHOWN = "com.unity3d.services.ads.api.AdViewer.markCampaignStateAsShown"
    const val LOAD_ERROR = "com.unity3d.services.ads.api.AdViewer.loadError"
    const val SEND_OPERATIVE_EVENT = "com.unity3d.services.ads.api.AdViewer.sendOperativeEvent"
    const val OPEN_URL = "com.unity3d.services.ads.api.AdViewer.openUrl"
    const val SET_ORIENTATION = "com.unity3d.services.ads.api.AdViewer.setOrientation"
    const val CANCEL_SHOW_TIMEOUT = "com.unity3d.services.ads.api.AdViewer.cancelShowTimeout"
    const val STARTED = "com.unity3d.services.ads.api.AdViewer.started"
    const val CLICKED = "com.unity3d.services.ads.api.AdViewer.clicked"
    const val COMPLETED = "com.unity3d.services.ads.api.AdViewer.completed"
    const val FAILED = "com.unity3d.services.ads.api.AdViewer.failed"
    const val STORAGE_READ = "com.unity3d.services.core.api.Storage.read"
    const val STORAGE_WRITE = "com.unity3d.services.core.api.Storage.write"
    const val STORAGE_CLEAR = "com.unity3d.services.core.api.Storage.clear"
    const val STORAGE_DELETE = "com.unity3d.services.core.api.Storage.delete"
    const val STORAGE_GET_KEYS = "com.unity3d.services.core.api.Storage.getKeys"
    const val STORAGE_GET = "com.unity3d.services.core.api.Storage.get"
    const val STORAGE_SET = "com.unity3d.services.core.api.Storage.set"
    const val GET_SESSION_TOKEN = "com.unity3d.services.ads.api.AdViewer.getSessionToken"
    const val GET_PRIVACY_FSM = "com.unity3d.services.ads.api.AdViewer.getPrivacyFsm"
    const val SET_PRIVACY_FSM = "com.unity3d.services.ads.api.AdViewer.setPrivacyFsm"
    const val SET_PRIVACY = "com.unity3d.services.ads.api.AdViewer.setPrivacyPayload"
    const val GET_PRIVACY = "com.unity3d.services.ads.api.AdViewer.getPrivacyPayload"
    const val BROADCAST_EVENT = "com.unity3d.services.ads.api.AdViewer.broadcastEvent"
    const val GET_ALLOWED_PII = "com.unity3d.services.ads.api.AdViewer.getPrivacyAllowedPii"
    const val SET_ALLOWED_PII = "com.unity3d.services.ads.api.AdViewer.setPrivacyAllowedPii"
    const val REFRESH_AD_DATA = "com.unity3d.services.ads.api.AdViewer.refreshAdData"
    const val UPDATE_TRACKING_TOKEN = "com.unity3d.services.ads.api.AdViewer.updateTrackingToken"
    const val REQUEST_GET = "com.unity3d.services.core.api.Request.get"
    const val REQUEST_POST = "com.unity3d.services.core.api.Request.post"
    const val REQUEST_HEAD = "com.unity3d.services.core.api.Request.head"
    const val SEND_PRIVACY_UPDATE_REQUEST = "com.unity3d.services.ads.api.AdViewer.sendPrivacyUpdateRequest"
    const val SEND_DIAGNOSTIC_EVENT = "com.unity3d.services.ads.api.AdViewer.sendDiagnosticEvent"
    const val INCREMENT_BANNER_IMPRESSION_COUNT = "com.unity3d.services.ads.api.AdViewer.incrementBannerImpressionCount"
    const val DOWNLOAD = "com.unity3d.services.ads.api.AdViewer.download"
    const val IS_FILE_CACHED = "com.unity3d.services.ads.api.AdViewer.isFileCached"
    const val LEFT_APPLICATION = "com.unity3d.services.ads.api.AdViewer.leftApplication"
    const val IS_ATTRIBUTION_AVAILABLE = "com.unity3d.services.ads.api.AdViewer.isAttributionAvailable"
    const val ATTRIBUTION_REGISTER_VIEW = "com.unity3d.services.ads.api.AdViewer.attributionRegisterView"
    const val ATTRIBUTION_REGISTER_CLICK = "com.unity3d.services.ads.api.AdViewer.attributionRegisterClick"
    const val LOAD_SCAR_AD = "com.unity3d.services.ads.api.AdViewer.loadScarAd"
    const val SHOW_SCAR_AD = "com.unity3d.services.ads.api.AdViewer.showScarAd"
    const val HEADER_BIDDING_TOKEN_INCREMENT_WINS = "com.unity3d.services.ads.api.AdViewer.hbTokenIncrementWins"
    const val HEADER_BIDDING_TOKEN_INCREMENT_STARTS = "com.unity3d.services.ads.api.AdViewer.hbTokenIncrementStarts"
    const val HEADER_BIDDING_TOKEN_RESET = "com.unity3d.services.ads.api.AdViewer.hbTokenReset"
    const val LOAD_OFFERWALL_AD = "com.unity3d.services.ads.api.AdViewer.loadOfferwallAd"
    const val SHOW_OFFERWALL_AD = "com.unity3d.services.ads.api.AdViewer.showOfferwallAd"
    const val IS_OFFERWALL_AD_READY = "com.unity3d.services.ads.api.AdViewer.isOfferwallAdReady"
    const val SET_OPPORTUNITY_TTL = "com.unity3d.services.ads.api.AdViewer.setOpportunityTTL"
}
